@@ -5,12 +5,17 @@
 
 Arrows <- function(x0, y0, x1, y1, code=2,
   arr.length=0.4, arr.width=arr.length/2, arr.adj=0.5,
-  arr.type="curved", segment=TRUE, lcol="black", lty=1,
-  arr.col=lcol, ...)  {
+  arr.type="curved", segment=TRUE, col="black", lcol=col, lty=1,
+  arr.col=lcol, lwd=2, arr.lwd=lwd, ...)  {
 
   if (arr.type=="simple") {
     arrows(x0,y0,x1,y1,code=code,length=arr.length/2.54,
-           col=arr.col,lty=lty,...)
+           lty=lty, col=col, lwd=lwd, ...)
+    return()
+  }
+  if (arr.type=="T") {
+    arrows(x0,y0,x1,y1,code=code,length=arr.length/(2*2.54),
+           lty=lty, angle=90, col=col, lwd=lwd,  ...)
     return()
   }
 
@@ -37,7 +42,7 @@ Arrows <- function(x0, y0, x1, y1, code=2,
     Arrowhead(x0=xx,y0=yy,angle=angle,
               lcol=lcol,arr.col=arr.col,arr.adj=arr.adj,
               lty=lty,arr.length=arr.length,arr.width=arr.width,
-              arr.type=arr.type)
+              arr.type=arr.type,arr.lwd=arr.lwd)
 
   if (code != 2) {
     angle <-180 + angle
@@ -47,7 +52,7 @@ Arrows <- function(x0, y0, x1, y1, code=2,
 
   Arrowhead(x0=xx,y0=yy,angle=angle,lcol=lcol,arr.col=arr.col,
             arr.adj=arr.adj,lty=lty,arr.length=arr.length,
-            arr.width=arr.width,arr.type=arr.type)
+            arr.width=arr.width,arr.type=arr.type,arr.lwd=arr.lwd)
 }
 
 
